=== modified file 'NEWS'
--- NEWS	2006-06-13 16:26:09 +0000
+++ NEWS	2006-06-16 15:40:20 +0000
@@ -51,7 +51,9 @@
    * 'bzr log --line' shows the revision number, and uses only the
      first line of the log message (#5162, Alexander Belchenko;
      Matthieu Moy)
-  
+
+   * 'bzr status' has had the --all option removed. The 'bzr ls' command
+     should be used to retrieve all versioned files. (Robert Collins)
 
   BUG FIXES:
 

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-06-13 12:55:45 +0000
+++ bzrlib/builtins.py	2006-06-16 10:18:34 +0000
@@ -132,10 +132,6 @@
     modified
         Text has changed since the previous revision.
 
-    unchanged
-        Nothing about this file has changed since the previous revision.
-        Only shown with --all.
-
     unknown
         Not versioned and not matching an ignore pattern.
 
@@ -154,18 +150,18 @@
     # TODO: --no-recurse, --recurse options
     
     takes_args = ['file*']
-    takes_options = ['all', 'show-ids', 'revision']
+    takes_options = ['show-ids', 'revision']
     aliases = ['st', 'stat']
 
     encoding_type = 'replace'
     
     @display_command
-    def run(self, all=False, show_ids=False, file_list=None, revision=None):
+    def run(self, show_ids=False, file_list=None, revision=None):
         from bzrlib.status import show_tree_status
 
         tree, file_list = tree_files(file_list)
             
-        show_tree_status(tree, show_unchanged=all, show_ids=show_ids,
+        show_tree_status(tree, show_ids=show_ids,
                          specific_files=file_list, revision=revision,
                          to_file=self.outf)
 

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2006-05-17 13:03:45 +0000
+++ bzrlib/status.py	2006-06-16 10:18:34 +0000
@@ -28,7 +28,7 @@
 
 
 @deprecated_function(zero_eight)
-def show_status(branch, show_unchanged=False,
+def show_status(branch, show_unchanged=None,
                 specific_files=None,
                 show_ids=False,
                 to_file=None,
@@ -69,7 +69,7 @@
                      specific_files, show_ids, to_file, show_pending, revision)
 
 
-def show_tree_status(wt, show_unchanged=False,
+def show_tree_status(wt, show_unchanged=None,
                      specific_files=None,
                      show_ids=False,
                      to_file=None,
@@ -87,29 +87,24 @@
     If showing the status of a working tree, extra information is included
     about unknown files, conflicts, and pending merges.
 
-    show_unchanged
-        If set, includes unchanged files.
-
-    specific_files
-        If set, a list of filenames whose status should be shown.
-        It is an error to give a filename that is not in the working 
+    :param show_unchanged: Deprecated parameter. If set, includes unchanged 
+        files.
+    :param specific_files: If set, a list of filenames whose status should be
+        shown.  It is an error to give a filename that is not in the working 
         tree, or in the working inventory or in the basis inventory.
-
-    show_ids
-        If set, includes each file's id.
-
-    to_file
-        If set, write to this file (default stdout.)
-
-    show_pending
-        If set, write pending merges.
-
-    revision
-        If None the compare latest revision with working tree
+    :param show_ids: If set, includes each file's id.
+    :param to_file: If set, write to this file (default stdout.)
+    :param show_pending: If set, write pending merges.
+    :param revision: If None the compare latest revision with working tree
+        If not None it must be a RevisionSpec list.
         If one revision show compared it with working tree.
         If two revisions show status between first and second.
     """
-    if to_file == None:
+    if show_unchanged is not None:
+        warn("show_status_trees with show_unchanged has been deprecated "
+             "since bzrlib 0.9", DeprecationWarning, stacklevel=2)
+
+    if to_file is None:
         to_file = sys.stdout
     
     wt.lock_read()

=== modified file 'bzrlib/tests/blackbox/test_too_much.py'
--- bzrlib/tests/blackbox/test_too_much.py	2006-06-06 22:59:58 +0000
+++ bzrlib/tests/blackbox/test_too_much.py	2006-06-16 15:40:20 +0000
@@ -696,12 +696,6 @@
         out = capture("status")
         self.assertEquals(out, 'unknown:\n  test.txt\n')
 
-        out = capture("status --all")
-        self.assertEquals(out, "unknown:\n  test.txt\n")
-
-        out = capture("status test.txt --all")
-        self.assertEquals(out, "unknown:\n  test.txt\n")
-
         f = file('test2.txt', 'wt')
         f.write('goodbye cruel world...\n')
         f.close()
@@ -715,7 +709,7 @@
         os.unlink('test2.txt')
 
         progress("command aliases")
-        out = capture("st --all")
+        out = capture("st")
         self.assertEquals(out, ("unknown:\n" "  test.txt\n"))
 
         out = capture("stat")
@@ -737,7 +731,6 @@
 
         runbzr("add test.txt")
         self.assertEquals(capture("unknowns"), '')
-        self.assertEquals(capture("status --all"), ("added:\n" "  test.txt\n"))
 
         progress("rename newly-added file")
         runbzr("rename test.txt hello.txt")

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2006-03-22 17:48:49 +0000
+++ bzrlib/tests/test_options.py	2006-06-16 15:40:20 +0000
@@ -15,8 +15,6 @@
         eq = self.assertEquals
         eq(parse_args(cmd_commit(), ['--help']),
            ([], {'help': True}))
-        eq(parse_args(cmd_status(), ['--all']),
-           ([], {'all': True}))
         eq(parse_args(cmd_commit(), ['--message=biter']),
            ([], {'message': 'biter'}))
         ## eq(parse_args(cmd_log(),  '-r 500'.split()),

